@@ -26,6 +26,8 @@
  * @ingroup Media
  */
 
+use Wikimedia\AtEase\AtEase;
+
 /**
  * GIF frame counter.
  *
@@ -46,7 +48,7 @@ class GIFMetadataExtractor {
 	// Each sub-block is less than or equal to 255 bytes.
 	// Most of the time its 255 bytes, except for in XMP
 	// blocks, where it's usually between 32-127 bytes each.
-	private const MAX_SUBBLOCKS = 262144; // 5mb divided by 20.
+	private const MAX_SUBBLOCKS = 262144; // 5 MiB divided by 20.
 
 	/**
 	 * @throws Exception
@@ -90,13 +92,16 @@ class GIFMetadataExtractor {
 
 		// Read BPP
 		$buf = fread( $fh, 1 );
-		$bpp = self::decodeBPP( $buf );
+		list( $bpp, $have_map ) = self::decodeBPP( $buf );
 
 		// Skip over background and aspect ratio
+		// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 		fread( $fh, 2 );
 
 		// Skip over the GCT
-		self::readGCT( $fh, $bpp );
+		if ( $have_map ) {
+			self::readGCT( $fh, $bpp );
+		}
 
 		while ( !feof( $fh ) ) {
 			$buf = fread( $fh, 1 );
@@ -106,14 +111,18 @@ class GIFMetadataExtractor {
 				$frameCount++;
 
 				# # Skip bounding box
+				// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 				fread( $fh, 8 );
 
 				# # Read BPP
 				$buf = fread( $fh, 1 );
-				$bpp = self::decodeBPP( $buf );
+				list( $bpp, $have_map ) = self::decodeBPP( $buf );
 
 				# # Read GCT
-				self::readGCT( $fh, $bpp );
+				if ( $have_map ) {
+					self::readGCT( $fh, $bpp );
+				}
+				// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 				fread( $fh, 1 );
 				self::skipBlock( $fh );
 			} elseif ( $buf == self::$gifExtensionSep ) {
@@ -125,8 +134,10 @@ class GIFMetadataExtractor {
 
 				if ( $extension_code == 0xF9 ) {
 					// Graphics Control Extension.
+					// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 					fread( $fh, 1 ); // Block size
 
+					// @phan-suppress-next-next-line PhanPluginUseReturnValueInternalKnown
 					// @phan-suppress-next-line PhanPluginDuplicateAdjacentStatement
 					fread( $fh, 1 ); // Transparency, disposal method, user input
 
@@ -137,6 +148,7 @@ class GIFMetadataExtractor {
 					$delay = unpack( 'v', $buf )[1];
 					$duration += $delay * 0.01;
 
+					// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 					fread( $fh, 1 ); // Transparent colour index
 
 					$term = fread( $fh, 1 ); // Should be a terminator
@@ -162,9 +174,9 @@ class GIFMetadataExtractor {
 					UtfNormal\Validator::quickIsNFCVerify( $dataCopy );
 
 					if ( $dataCopy !== $data ) {
-						Wikimedia\suppressWarnings();
+						AtEase::suppressWarnings();
 						$data = iconv( 'windows-1252', 'UTF-8', $data );
-						Wikimedia\restoreWarnings();
+						AtEase::restoreWarnings();
 					}
 
 					$commentCount = count( $comment );
@@ -214,6 +226,7 @@ class GIFMetadataExtractor {
 						}
 
 						// Read out terminator byte
+						// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 						fread( $fh, 1 );
 					} elseif ( $data == 'XMP DataXMP' ) {
 						// application name for XMP data.
@@ -224,7 +237,6 @@ class GIFMetadataExtractor {
 						if ( substr( $xmp, -257, 3 ) !== "\x01\xFF\xFE"
 							|| substr( $xmp, -4 ) !== "\x03\x02\x01\x00"
 						) {
-							// this is just a sanity check.
 							throw new Exception( "XMP does not have magic trailer!" );
 						}
 
@@ -234,7 +246,6 @@ class GIFMetadataExtractor {
 						// unrecognized extension block
 						fseek( $fh, -( $blockLength + 1 ), SEEK_CUR );
 						self::skipBlock( $fh );
-						continue;
 					}
 				} else {
 					self::skipBlock( $fh );
@@ -256,6 +267,9 @@ class GIFMetadataExtractor {
 			'duration' => $duration,
 			'xmp' => $xmp,
 			'comment' => $comment,
+			'width' => $width,
+			'height' => $height,
+			'bits' => $bpp,
 		];
 	}
 
@@ -265,18 +279,17 @@ class GIFMetadataExtractor {
 	 * @return void
 	 */
 	private static function readGCT( $fh, $bpp ) {
-		if ( $bpp > 0 ) {
-			$max = 2 ** $bpp;
-			for ( $i = 1; $i <= $max; ++$i ) {
-				fread( $fh, 3 );
-			}
+		$max = 2 ** $bpp;
+		for ( $i = 1; $i <= $max; ++$i ) {
+			// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
+			fread( $fh, 3 );
 		}
 	}
 
 	/**
 	 * @param string $data
 	 * @throws Exception
-	 * @return int
+	 * @return array [ int bits per channel, bool have GCT ]
 	 */
 	private static function decodeBPP( $data ) {
 		if ( strlen( $data ) < 1 ) {
@@ -288,7 +301,7 @@ class GIFMetadataExtractor {
 
 		$have_map = $buf & 1;
 
-		return $have_map ? $bpp : 0;
+		return [ $bpp, $have_map ];
 	}
 
 	/**
@@ -305,6 +318,7 @@ class GIFMetadataExtractor {
 			if ( $block_len == 0 ) {
 				return;
 			}
+			// @phan-suppress-next-line PhanPluginUseReturnValueInternalKnown
 			fread( $fh, $block_len );
 		}
 	}
