@@ -19,13 +19,18 @@
  * @ingroup Pager
  */
 
-use MediaWiki\MediaWikiServices;
+use MediaWiki\Cache\LinkBatchFactory;
+use MediaWiki\Page\PageIdentity;
+use MediaWiki\Revision\RevisionStore;
+use Wikimedia\Rdbms\ILoadBalancer;
 
 /**
  * @ingroup Pager
  */
 class MergeHistoryPager extends ReverseChronologicalPager {
 
+	public $mGroupByDate = true;
+
 	/** @var SpecialMergeHistory */
 	public $mForm;
 
@@ -38,33 +43,60 @@ class MergeHistoryPager extends ReverseChronologicalPager {
 	/** @var int */
 	private $maxTimestamp;
 
-	public function __construct( SpecialMergeHistory $form, $conds, Title $source, Title $dest ) {
+	/** @var LinkBatchFactory */
+	private $linkBatchFactory;
+
+	/** @var RevisionStore */
+	private $revisionStore;
+
+	/**
+	 * @param SpecialMergeHistory $form
+	 * @param LinkBatchFactory $linkBatchFactory
+	 * @param ILoadBalancer $loadBalancer
+	 * @param RevisionStore $revisionStore
+	 * @param array $conds
+	 * @param PageIdentity $source
+	 * @param PageIdentity $dest
+	 */
+	public function __construct(
+		SpecialMergeHistory $form,
+		LinkBatchFactory $linkBatchFactory,
+		ILoadBalancer $loadBalancer,
+		RevisionStore $revisionStore,
+		$conds,
+		PageIdentity $source,
+		PageIdentity $dest
+	) {
 		$this->mForm = $form;
 		$this->mConds = $conds;
-		$this->articleID = $source->getArticleID();
+		$this->articleID = $source->getId();
 
-		$dbr = wfGetDB( DB_REPLICA );
+		$dbr = $loadBalancer->getConnectionRef( ILoadBalancer::DB_REPLICA );
 		$maxtimestamp = $dbr->selectField(
 			'revision',
 			'MIN(rev_timestamp)',
-			[ 'rev_page' => $dest->getArticleID() ],
+			[ 'rev_page' => $dest->getId() ],
 			__METHOD__
 		);
 		$this->maxTimestamp = $maxtimestamp;
 
+		// Set database before parent constructor to avoid setting it there with wfGetDB
+		$this->mDb = $dbr;
 		parent::__construct( $form->getContext() );
+		$this->linkBatchFactory = $linkBatchFactory;
+		$this->revisionStore = $revisionStore;
 	}
 
-	protected function getStartBody() {
+	protected function doBatchLookups() {
 		# Do a link batch query
 		$this->mResult->seek( 0 );
-		$batch = new LinkBatch();
+		$batch = $this->linkBatchFactory->newLinkBatch();
 		# Give some pointers to make (last) links
 		$this->mForm->prevId = [];
 		$rev_id = null;
 		foreach ( $this->mResult as $row ) {
-			$batch->addObj( Title::makeTitleSafe( NS_USER, $row->user_name ) );
-			$batch->addObj( Title::makeTitleSafe( NS_USER_TALK, $row->user_name ) );
+			$batch->add( NS_USER, $row->rev_user_text );
+			$batch->add( NS_USER_TALK, $row->rev_user_text );
 
 			if ( isset( $rev_id ) ) {
 				if ( $rev_id > $row->rev_id ) {
@@ -79,8 +111,20 @@ class MergeHistoryPager extends ReverseChronologicalPager {
 
 		$batch->execute();
 		$this->mResult->seek( 0 );
+	}
 
-		return '';
+	/**
+	 * @inheritDoc
+	 */
+	protected function getStartBody() {
+		return "<section class='mw-pager-body'>\n";
+	}
+
+	/**
+	 * @inheritDoc
+	 */
+	protected function getEndBody() {
+		return "</section>\n";
 	}
 
 	public function formatRow( $row ) {
@@ -88,21 +132,29 @@ class MergeHistoryPager extends ReverseChronologicalPager {
 	}
 
 	public function getQueryInfo() {
+		$dbr = $this->getDatabase();
 		$conds = $this->mConds;
 		$conds['rev_page'] = $this->articleID;
-		$conds[] = "rev_timestamp < " . $this->mDb->addQuotes( $this->maxTimestamp );
+		$conds[] = "rev_timestamp < " . $dbr->addQuotes( $this->maxTimestamp );
 
-		// TODO inject a RevisionStore into SpecialMergeHistory and pass it to
-		// the MergeHistoryPager constructor
-		$revQuery = MediaWikiServices::getInstance()
-			->getRevisionStore()
-			->getQueryInfo( [ 'page', 'user' ] );
-		return [
-			'tables' => $revQuery['tables'],
-			'fields' => $revQuery['fields'],
-			'conds' => $conds,
-			'join_conds' => $revQuery['joins']
-		];
+		$queryInfo = $this->revisionStore->getQueryInfo( [ 'page', 'user' ] );
+		$queryInfo['conds'] = $conds;
+		$queryInfo['options'] = [];
+
+		// rename the "joins" field to "join_conds" as expected by the base class.
+		$queryInfo['join_conds'] = $queryInfo['joins'];
+		unset( $queryInfo['joins'] );
+
+		ChangeTags::modifyDisplayQuery(
+			$queryInfo['tables'],
+			$queryInfo['fields'],
+			$queryInfo['conds'],
+			$queryInfo['join_conds'],
+			$queryInfo['options'],
+			''
+		);
+
+		return $queryInfo;
 	}
 
 	public function getIndexField() {
