@@ -21,6 +21,8 @@
  * @ingroup Maintenance
  */
 
+use MediaWiki\MediaWikiServices;
+
 require_once __DIR__ . '/Maintenance.php';
 
 /**
@@ -41,7 +43,7 @@ class ManageJobs extends Maintenance {
 		$type = $this->getOption( 'type' );
 		$action = $this->getOption( 'action' );
 
-		$group = JobQueueGroup::singleton();
+		$group = MediaWikiServices::getInstance()->getJobQueueGroup();
 		$queue = $group->get( $type );
 
 		if ( $action === 'delete' ) {
