@@ -23,6 +23,8 @@
  * @ingroup Maintenance
  */
 
+use MediaWiki\MainConfigNames;
+
 require_once __DIR__ . '/Maintenance.php';
 
 /**
@@ -42,13 +44,13 @@ class RenameDbPrefix extends Maintenance {
 	}
 
 	public function execute() {
-		global $wgDBname;
+		$dbName = $this->getConfig()->get( MainConfigNames::DBname );
 
 		// Allow for no old prefix
 		if ( $this->getOption( 'old', 0 ) === '0' ) {
 			$old = '';
 		} else {
-			// Use nice safe, sane, prefixes
+			// Use nice safe, sensible, prefixes
 			preg_match( '/^[a-zA-Z]+_$/', $this->getOption( 'old' ), $m );
 			$old = $m[0] ?? false;
 		}
@@ -56,7 +58,7 @@ class RenameDbPrefix extends Maintenance {
 		if ( $this->getOption( 'new', 0 ) === '0' ) {
 			$new = '';
 		} else {
-			// Use nice safe, sane, prefixes
+			// Use nice safe, sensible, prefixes
 			preg_match( '/^[a-zA-Z]+_$/', $this->getOption( 'new' ), $m );
 			$new = $m[0] ?? false;
 		}
@@ -68,10 +70,10 @@ class RenameDbPrefix extends Maintenance {
 			$this->output( "Same prefix. Nothing to rename!\n", true );
 		}
 
-		$this->output( "Renaming DB prefix for tables of $wgDBname from '$old' to '$new'\n" );
+		$this->output( "Renaming DB prefix for tables of $dbName from '$old' to '$new'\n" );
 		$count = 0;
 
-		$dbw = $this->getDB( DB_MASTER );
+		$dbw = $this->getDB( DB_PRIMARY );
 		$res = $dbw->query( "SHOW TABLES " . $dbw->buildLike( $old, $dbw->anyString() ), __METHOD__ );
 		foreach ( $res as $row ) {
 			// XXX: odd syntax. MySQL outputs an oddly cased "Tables of X"
