@@ -1,6 +1,6 @@
 <?php
 
-use MediaWiki\MediaWikiServices;
+use MediaWiki\MainConfigNames;
 use Wikimedia\Rdbms\LoadBalancerSingle;
 
 /**
@@ -21,7 +21,7 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	 * Checks for database type & version.
 	 * Will skip current test if DB does not support search.
 	 */
-	protected function setUp() : void {
+	protected function setUp(): void {
 		parent::setUp();
 
 		// Search tests require MySQL or SQLite with FTS
@@ -34,20 +34,20 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 		}
 
 		$searchType = SearchEngineFactory::getSearchEngineClass( $this->db );
-		$this->setMwGlobals( [
-			'wgSearchType' => $searchType,
-			'wgCapitalLinks' => true,
-			'wgCapitalLinkOverrides' => [
+		$this->overrideConfigValues( [
+			MainConfigNames::SearchType => $searchType,
+			MainConfigNames::CapitalLinks => true,
+			MainConfigNames::CapitalLinkOverrides => [
 				NS_CATEGORY => false // for testCompletionSearchMustRespectCapitalLinkOverrides
 			],
 		] );
 
 		$lb = LoadBalancerSingle::newFromConnection( $this->db );
 		$this->search = new $searchType( $lb );
-		$this->search->setHookContainer( MediaWikiServices::getInstance()->getHookContainer() );
+		$this->search->setHookContainer( $this->getServiceContainer()->getHookContainer() );
 	}
 
-	protected function tearDown() : void {
+	protected function tearDown(): void {
 		unset( $this->search );
 
 		parent::tearDown();
@@ -61,10 +61,10 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 
 		// Reset the search type back to default - some extensions may have
 		// overridden it.
-		$this->setMwGlobals( [
-			'wgSearchType' => null,
-			'wgCapitalLinks' => true,
-			'wgCapitalLinkOverrides' => [
+		$this->overrideConfigValues( [
+			MainConfigNames::SearchType => null,
+			MainConfigNames::CapitalLinks => true,
+			MainConfigNames::CapitalLinkOverrides => [
 				NS_CATEGORY => false // for testCompletionSearchMustRespectCapitalLinkOverrides
 			],
 		] );
@@ -115,6 +115,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testFullWidth() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->assertEquals(
 			[ 'FullOneUp', 'FullTwoLow', 'HalfOneUp', 'HalfTwoLow' ],
 			$this->fetchIds( $this->search->searchText( 'AZ' ) ),
@@ -134,6 +136,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testTextSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->assertEquals(
 			[ 'Smithee' ],
 			$this->fetchIds( $this->search->searchText( 'smithee' ) ),
@@ -141,6 +145,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testWildcardSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$res = $this->search->searchText( 'smith*' );
 		$this->assertEquals(
 			[ 'Smithee' ],
@@ -167,6 +173,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testPhraseSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$res = $this->search->searchText( '"smithee is one who smiths"' );
 		$this->assertEquals(
 			[ 'Smithee' ],
@@ -187,6 +195,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testPhraseSearchHighlight() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$phrase = "smithee is one who smiths";
 		$res = $this->search->searchText( "\"$phrase\"" );
 		$match = $res->getIterator()->current();
@@ -197,6 +207,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testTextPowerSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->search->setNamespaces( [ 0, 1, 4 ] );
 		$this->assertEquals(
 			[
@@ -208,6 +220,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testTitleSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->assertEquals(
 			[
 				'Alan Smithee',
@@ -218,6 +232,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testTextTitlePowerSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->search->setNamespaces( [ 0, 1, 4 ] );
 		$this->assertEquals(
 			[
@@ -246,6 +262,11 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 				'Category:Search is not search',
 				[ NS_CATEGORY ],
 			],
+			'Copy-pasted wikilinks with invalid characters will still find the page' => [
+				'[[smithee]]',
+				'Smithee',
+				[ NS_MAIN ],
+			],
 		];
 	}
 
@@ -279,7 +300,7 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 		 * @var SearchEngine $mockEngine
 		 */
 		$mockEngine = $this->getMockBuilder( SearchEngine::class )
-			->setMethods( [ 'makeSearchFieldMapping' ] )->getMock();
+			->onlyMethods( [ 'makeSearchFieldMapping' ] )->getMock();
 
 		$mockFieldBuilder = function ( $name, $type ) {
 			$mockField =
@@ -288,14 +309,13 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 					$type,
 				] )->getMock();
 
-			$mockField->expects( $this->any() )->method( 'getMapping' )->willReturn( [
+			$mockField->method( 'getMapping' )->willReturn( [
 				'testData' => 'test',
 				'name' => $name,
 				'type' => $type,
 			] );
 
-			$mockField->expects( $this->any() )
-				->method( 'merge' )
+			$mockField->method( 'merge' )
 				->willReturn( $mockField );
 
 			return $mockField;
@@ -307,12 +327,12 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 
 		// Not using mock since PHPUnit mocks do not work properly with references in params
 		$this->setTemporaryHook( 'SearchIndexFields',
-			function ( &$fields, SearchEngine $engine ) use ( $mockFieldBuilder ) {
+			static function ( &$fields, SearchEngine $engine ) use ( $mockFieldBuilder ) {
 				$fields['testField'] =
 					$mockFieldBuilder( "testField", SearchIndexField::INDEX_TYPE_TEXT );
 				return true;
 			} );
-		$mockEngine->setHookContainer( MediaWikiServices::getInstance()->getHookContainer() );
+		$mockEngine->setHookContainer( $this->getServiceContainer()->getHookContainer() );
 
 		$fields = $mockEngine->getSearchIndexFields();
 		$this->assertArrayHasKey( 'language', $fields );
@@ -330,6 +350,8 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 	}
 
 	public function testAugmentorSearch() {
+		// T303046
+		$this->markTestSkippedIfDbType( 'sqlite' );
 		$this->search->setNamespaces( [ 0, 1, 4 ] );
 		$resultSet = $this->search->searchText( 'smithee' );
 		// Not using mock since PHPUnit mocks do not work properly with references in params
@@ -349,7 +371,7 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 		$setAugmentor = $this->createMock( ResultSetAugmentor::class );
 		$setAugmentor->expects( $this->once() )
 			->method( 'augmentAll' )
-			->willReturnCallback( function ( ISearchResultSet $resultSet ) {
+			->willReturnCallback( static function ( ISearchResultSet $resultSet ) {
 				$data = [];
 				/** @var SearchResult $result */
 				foreach ( $resultSet as $result ) {
@@ -363,7 +385,7 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 		$rowAugmentor = $this->createMock( ResultAugmentor::class );
 		$rowAugmentor->expects( $this->exactly( 2 ) )
 			->method( 'augment' )
-			->willReturnCallback( function ( SearchResult $result ) {
+			->willReturnCallback( static function ( SearchResult $result ) {
 				$id = $result->getTitle()->getArticleID();
 				return "Result2:$id:" . $result->getTitle()->getText();
 			} );
@@ -384,7 +406,7 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 
 		$engine = new MockCompletionSearchEngine();
 		$engine->setLimitOffset( 10, 0 );
-		$engine->setHookContainer( MediaWikiServices::getInstance()->getHookContainer() );
+		$engine->setHookContainer( $this->getServiceContainer()->getHookContainer() );
 		$results = $engine->completionSearch( 'foo' );
 		$this->assertEquals( 5, $results->getSize() );
 		$this->assertTrue( $results->hasMoreResults() );
@@ -397,8 +419,9 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 
 	private function editSearchResultPage( $title ) {
 		$page = WikiPage::factory( Title::newFromText( $title ) );
-		$page->doEditContent(
+		$page->doUserEditContent(
 			new WikitextContent( 'UTContent' ),
+			$this->getTestSysop()->getUser(),
 			'UTPageSummary',
 			EDIT_NEW | EDIT_SUPPRESS_RC
 		);
@@ -484,13 +507,9 @@ class SearchEngineTest extends MediaWikiLangTestCase {
 
 	/**
 	 * @dataProvider provideDataForParseNamespacePrefix
-	 * @param array $params
-	 * @param array|false $expected
-	 * @throws FatalError
-	 * @throws MWException
 	 */
 	public function testParseNamespacePrefix( array $params, $expected ) {
-		$this->setTemporaryHook( 'PrefixSearchExtractNamespace', function ( &$namespaces, &$query ) {
+		$this->setTemporaryHook( 'PrefixSearchExtractNamespace', static function ( &$namespaces, &$query ) {
 			if ( strpos( $query, 'hélp:' ) === 0 ) {
 				$namespaces = [ NS_HELP ];
 				$query = substr( $query, strlen( 'hélp:' ) );
